"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeLineScopeTracker = void 0;
class CodeLineScopeTracker {
    static create(numLines) {
        const nodes = new Array(numLines).fill([]).map(() => []);
        const scopes = new Array(numLines).fill(new Set());
        const headers = new Array(numLines)
            .fill([])
            .map(() => []);
        return new CodeLineScopeTracker(numLines, nodes, scopes, headers);
    }
    constructor(numLines, nodes, scopes, headers) {
        this.numLines = numLines;
        this.nodes = nodes;
        this.scopes = scopes;
        this.headers = headers;
    }
    withScopeDataInitialized(node, depth = 0) {
        const startLine = node.startPosition.row;
        const endLine = node.endPosition.row;
        const size = endLine - startLine;
        this.nodes[startLine].push(node);
        if (size) {
            this.headers[startLine].push([size, startLine, endLine]);
        }
        for (let i = startLine; i <= endLine; i++) {
            this.scopes[i].add(startLine);
        }
        node.children.forEach(child => this.withScopeDataInitialized(child, depth + 1));
        return this;
    }
    toDominantScopeBlockRepresentation(mapOptions) {
        const headerMax = mapOptions.headerMax;
        const header = new Array(this.numLines).fill([0, 0, 0]);
        for (let i = 0; i < this.numLines; i++) {
            const headers = this.headers[i].sort((a, b) => a[0] - b[0]);
            let [size, headStart, headEnd] = [1, i, i + 1];
            if (headers.length > 1) {
                [size, headStart, headEnd] = headers[0];
                if (size > headerMax) {
                    headEnd = headStart + headerMax;
                }
            }
            header[i] = [size, headStart, headEnd];
        }
        return header;
    }
}
exports.CodeLineScopeTracker = CodeLineScopeTracker;
//# sourceMappingURL=CodeLineScopeTracker.js.map