"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScopeLineIntegrator = void 0;
const lodash_1 = __importDefault(require("lodash"));
const SourceCodeHighlighter_1 = require("./SourceCodeHighlighter");
class ScopeLineIntegrator {
    constructor(codeLines, scopes, header) {
        this.codeLines = codeLines;
        this.scopes = scopes;
        this.header = header;
    }
    toCodeHighlighter(lineNumbers) {
        const linesOfInterest = new Set(lineNumbers);
        if (linesOfInterest.size === 0) {
            return;
        }
        const showLines = new Set(linesOfInterest);
        this.includeLinesFromParentScopes(linesOfInterest).forEach(lineNum => {
            showLines.add(lineNum);
        });
        return new SourceCodeHighlighter_1.SourceCodeHighlighter(this.codeLines, Array.from(linesOfInterest).sort(), Array.from(showLines).sort(), this.scopes);
    }
    includeLinesFromParentScopes(linesOfInterest) {
        return new Set(Array.from(linesOfInterest).reduce((acc, scopeStart) => {
            const header = this.header[scopeStart];
            if (header.length > 0) {
                const [_size, start, end] = header;
                return lodash_1.default.range(start, end).reduce((accI, i) => {
                    return accI.add(i);
                }, acc);
            }
            else {
                return acc.add(scopeStart);
            }
        }, new Set()));
    }
}
exports.ScopeLineIntegrator = ScopeLineIntegrator;
//# sourceMappingURL=ScopeLineIntegrator.js.map