"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateFileHighlights = void 0;
const ranker_1 = require("../ranker");
const common_1 = require("./common");
const CodeLineScopeTracker_1 = require("./CodeLineScopeTracker");
const ScopeLineIntegrator_1 = require("./ScopeLineIntegrator");
const mapOptions = new common_1.HighlightConfiguration(10);
function generateFileHighlights(relPath, code, linesOfInterest, contentPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const language = (0, ranker_1.getLinguistLanguage)(relPath);
        const codeLines = code.split('\n');
        if (!language)
            return;
        const wasmPath = contentPath.getWasmURL(language);
        const ast = yield ranker_1.AST.createFromCode(relPath, code, wasmPath, language);
        const scopeTracker = CodeLineScopeTracker_1.CodeLineScopeTracker.create(codeLines.length).withScopeDataInitialized(ast.tree.rootNode);
        const header = scopeTracker.toDominantScopeBlockRepresentation(mapOptions);
        const scopeIntegrator = new ScopeLineIntegrator_1.ScopeLineIntegrator(codeLines, scopeTracker.scopes, header);
        const codeHighlighter = scopeIntegrator.toCodeHighlighter(linesOfInterest);
        if (!codeHighlighter)
            return;
        const highlights = codeHighlighter.withSmallGapsClosed().toFormattedString();
        return `\n${relPath}\n${highlights}`;
    });
}
exports.generateFileHighlights = generateFileHighlights;
//# sourceMappingURL=index.js.map