"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRepoHighlights = void 0;
const index_shared_1 = require("./index.shared");
const ContentPath_node_1 = require("./ranker/ContentPath.node");
/**
 * Generates highlights for a repository by selecting the top percentile of ranked tags from non-chat sources.
 *
 * It ranks all tags across the repository using PageRank, filters out tags from chat sources,
 * takes the top percentile of tags, groups them by file, and generates highlights for each file.
 *
 * The highlights are concatenated and returned.
 *
 * @param topPercentile - The percentile of top ranked tags to use for highlights.
 * @param chatSources - The source code files that are from chat.
 * @param otherSources - The source code files that are not from chat.
 * @returns The concatenated highlights for the top percentile of non-chat tags.
 */
function getRepoHighlights(topPercentile, chatSources, otherSources) {
    return __awaiter(this, void 0, void 0, function* () {
        return (0, index_shared_1.generateRepoHighlights)(topPercentile, chatSources, otherSources, new ContentPath_node_1.NodeContentPath());
    });
}
exports.getRepoHighlights = getRepoHighlights;
//# sourceMappingURL=index.node.js.map