"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateRepoHighlights = void 0;
const lodash_1 = __importDefault(require("lodash"));
const ranker_1 = require("./ranker");
const highlighter_1 = require("./highlighter");
function createRankedTags(sources, contentPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const extractor = new ranker_1.CodeTagExtractor('', contentPath);
        const defRefs = yield ranker_1.DefRefs.create(extractor, sources);
        if (!defRefs)
            return;
        const tagRanker = defRefs.createTagranker();
        if (!tagRanker)
            return;
        return tagRanker.pagerank();
    });
}
function generateFileHighlightsFromTags(tags, code, contentPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const relPath = tags[0].relPath;
        const linesOfInterest = tags.map(tag => tag.start.ln - 1);
        return (0, highlighter_1.generateFileHighlights)(relPath, code, linesOfInterest, contentPath);
    });
}
function generateRepoHighlights(topPercentile, chatSources, otherSources, contentPath) {
    return __awaiter(this, void 0, void 0, function* () {
        if (topPercentile <= 0 || 1 < topPercentile)
            throw new Error('topPercentile must be between 0 and 1');
        const allSources = [...chatSources, ...otherSources];
        const rankedTags = yield createRankedTags(allSources, contentPath);
        if (!rankedTags)
            return;
        const chatRelPaths = chatSources.map(source => source.relPath);
        const topTags = rankedTags.without(chatRelPaths).toTags();
        const maxTags = lodash_1.default.round(topPercentile * topTags.length);
        const mapTags = topTags.slice(0, maxTags);
        const sortedTags = lodash_1.default.orderBy(mapTags, ['relPath', 'start.ln'], ['asc', 'asc']);
        const groupedTags = lodash_1.default.groupBy(sortedTags, tag => tag.relPath);
        const fileHighlights = lodash_1.default.values(groupedTags).map(tags => {
            const relPath = tags[0].relPath;
            const code = allSources.find(source => source.relPath === relPath).code;
            return generateFileHighlightsFromTags(tags, code, contentPath);
        });
        return lodash_1.default.join(fileHighlights, '');
    });
}
exports.generateRepoHighlights = generateRepoHighlights;
//# sourceMappingURL=index.shared.js.map