"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeTagExtractor = void 0;
const lang_utils_1 = require("./lang-utils");
const AST_1 = require("./AST");
const Tagger_1 = require("./Tagger");
class CodeTagExtractor {
    constructor(workspacePath, contentPath) {
        this.workspacePath = workspacePath;
        this.contentPath = contentPath;
    }
    extractTags(relPath, code) {
        return __awaiter(this, void 0, void 0, function* () {
            const language = (0, lang_utils_1.getLanguage)(relPath);
            if (!language)
                return [];
            const wasmPath = this.contentPath.getWasmURL(language);
            const ast = yield AST_1.AST.createFromCode(relPath, code, wasmPath, language);
            const tagger = Tagger_1.Tagger.create(ast, this.contentPath.getQuery(language));
            return tagger.read();
        });
    }
}
exports.CodeTagExtractor = CodeTagExtractor;
//# sourceMappingURL=CodeTagExtractor.js.map