"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefRefs = void 0;
const TagRanker_1 = require("./TagRanker");
class DefRefs {
    static create(tagGetter, sources) {
        return __awaiter(this, void 0, void 0, function* () {
            const defRefs = yield Promise.all(sources.map((source) => __awaiter(this, void 0, void 0, function* () {
                const tags = yield tagGetter.extractTags(source.relPath, source.code);
                const defs = tags.filter(tag => tag.kind === 'def');
                const refs = tags.filter(tag => tag.kind === 'ref');
                return { relPath: source.relPath, all: tags, defs: defs, refs: refs };
            })));
            const nonEmpty = defRefs.filter(defRef => defRef.defs.length != 0 || defRef.refs.length != 0);
            if (nonEmpty.length == 0)
                return;
            return new DefRefs(tagGetter.workspacePath, nonEmpty);
        });
    }
    constructor(workspacePath, defRefs) {
        this.workspacePath = workspacePath;
        this.defRefs = defRefs;
    }
    static _add(map, key, value) {
        var _a;
        if (!map.has(key))
            map.set(key, new Set());
        (_a = map.get(key)) === null || _a === void 0 ? void 0 : _a.add(value);
    }
    static _push(map, key, value) {
        var _a;
        if (!map.has(key))
            map.set(key, []);
        (_a = map.get(key)) === null || _a === void 0 ? void 0 : _a.push(value);
    }
    createTagranker() {
        const defines = new Map();
        this.defRefs.forEach(defRef => {
            defRef.defs.forEach(def => {
                DefRefs._add(defines, def.text, defRef.relPath);
            });
        });
        const definitions = new Map();
        this.defRefs.forEach(defRef => {
            defRef.defs.forEach(tag => {
                DefRefs._add(definitions, `${defRef.relPath},${tag.text}`, tag);
            });
        });
        const references = new Map();
        this.defRefs.forEach(defRef => {
            defRef.refs.forEach(tag => {
                DefRefs._push(references, tag.text, defRef.relPath);
            });
        });
        if (references.size === 0) {
            defines.forEach((value, key) => {
                references.set(key, Array.from(value));
            });
        }
        const relPaths = this.defRefs.map(defRef => {
            return defRef.relPath;
        });
        if (defines.size === 0 || definitions.size === 0 || references.size === 0)
            return;
        const identifiers = Array.from(defines.keys()).filter(key => references.has(key));
        return new TagRanker_1.TagRanker(this.workspacePath, relPaths, defines, definitions, references, identifiers);
    }
}
exports.DefRefs = DefRefs;
//# sourceMappingURL=DefRefs.js.map